#
# spec file for package redshift
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           redshift
Version:        1.11
Release:        3.4
Summary:        Adjusts the color temperature of your screen
License:        GPL-3.0
Group:          System/X11/Utilities
Url:            http://jonls.dk/redshift/
Source:         https://github.com/jonls/redshift/releases/download/v%{version}/%{name}-%{version}.tar.xz 
BuildRequires:  fdupes
BuildRequires:  gettext-tools
BuildRequires:  hicolor-icon-theme
BuildRequires:  intltool
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(gconf-2.0)
BuildRequires:  pkgconfig(geoclue-2.0)
BuildRequires:  pkgconfig(libdrm)
BuildRequires:  pkgconfig(python3)
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(xcb)
BuildRequires:  pkgconfig(xrandr)
BuildRequires:  pkgconfig(xxf86vm)
Requires:       geoclue2
Requires:       python3-xdg
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
%if 0%{?suse_version} > 1320
BuildRequires:  systemd-rpm-macros
%{?systemd_requires}
%endif
%py_requires

%description
Redshift adjusts the color temperature of your screen according to your surroundings.
This may help your eyes hurt less if you are working in front of the screen at night.

%package gtk
Summary:        Gtk frontend for redshift
Group:          System/X11/Utilities
Requires:       hicolor-icon-theme
Requires:       redshift = %{version}-%{release}
Requires:       python3-gobject-Gdk
Requires(post): update-desktop-files
Requires(post): hicolor-icon-theme
Requires(postun): update-desktop-files
Requires(postun): hicolor-icon-theme
%if 0%{?suse_version} > 1320
%{?systemd_requires}
%endif

%description gtk
A graphical user interface for the redshift tool that integrates into Gtk+ and GNOME.

%prep
%setup -q

%build
%configure \
  --enable-gui \
  --disable-geoclue \
  --enable-geoclue2 \
  --enable-randr \
  --enable-vidmode \
  %if 0%{?suse_version} > 1320
  --with-systemduserunitdir=%{_userunitdir}
  %else
  --with-systemduserunitdir=no
  %endif
make %{?_smp_mflags} V=1

%install
make %{?_smp_mflags} DESTDIR=%{buildroot} install
%fdupes -s %{buildroot}%{python3_sitelib}
%suse_update_desktop_file redshift-gtk GTK X-SuSE-DesktopUtility

%if 0%{?suse_version} == 1310
rm %{buildroot}%{_datadir}/appdata/redshift-gtk.appdata.xml
%endif

%find_lang %{name}

%post gtk
%desktop_database_post
%icon_theme_cache_post

%postun gtk
%desktop_database_postun
%icon_theme_cache_postun

%files gtk -f %{name}.lang
%defattr(-,root,root,-)
%{_bindir}/redshift-gtk
%{python3_sitelib}/redshift_gtk
%{_datadir}/applications/redshift-gtk.desktop
%{_datadir}/icons/hicolor/scalable/apps/redshift-status-off.svg
%{_datadir}/icons/hicolor/scalable/apps/redshift-status-on.svg
%{_datadir}/icons/hicolor/scalable/apps/redshift.svg
%if 0%{?suse_version} > 1320
%{_userunitdir}/redshift-gtk.service
%endif
%if 0%{?suse_version} > 1310
%dir %{_datadir}/appdata
%{_datadir}/appdata/redshift-gtk.appdata.xml
%endif

%files
%defattr(-,root,root,-)
%{_bindir}/redshift
%{_mandir}/man1/redshift.1%{ext_man}
%{_datadir}/applications/redshift.desktop
%if 0%{?suse_version} > 1320
%{_userunitdir}/redshift.service
%endif

%changelog
* Wed May  4 2016 zaitor@opensuse.org
- Add explict Requires python-gobject-Gdk for gtk subpackage,
  needed after the spilt of python3-gobject.
- Drop autoconf and automake BuildRequires: They are not needed.
* Tue Apr  5 2016 dimstar@opensuse.org
- Run fdupes only over %%{python3_sitelib}, ensuring that the files
  in /usr/share/icons/hicolor remain actual files and cannot be
  accidentally converted to symlinks.
* Sun Feb  7 2016 mpluskal@suse.com
- Make building more verbose
- Update post/postun dependencies of -gtk subpackage
- Small spec file cleanups
- Fix building for Leap
* Tue Jan 19 2016 zaitor@opensuse.org
- Add pkgconfig(libdrm) BuildRequires: Build support for DRM
  adjustement method.
- Change --with-systemduserunitdir=no to
  - -with-systemduserunitdir=%%{_userunitdir} and package the
  produced service files. Users can do systemctl enable/disable
  - -user redshift.service or redshift-gtk.service depending on what
  package they install/want.
* Sat Jan 16 2016 mimi.vx@gmail.com
- update to 1.11
  * Add option preserve for gamma adjustment methods (randr, vidmode, quartz, w32gdi)
    to apply redness on top of current gamma correction.
  * Add redshift.desktop file to resolve an issue where Geoclue2 would not allow
    redshift to obtain the current location
  * Make sure that the child process is terminated when redshift-gtk exits.
  * A sample configuation file has been added to the distribution tarball.
  * Fix warning message in redshift-gtk that is some cases caused redshift-gtk to fail
  * Use nanosleep() for sleeping to avoid high CPU load on platforms (NetBSD, ...)
    with limitations in usleep()
  * Various updates to man page and translations.
* Fri Sep 11 2015 mimi.vx@gmail.com
- fix build on openSUSE:Leap
* Fri Feb 20 2015 mimi.vx@gmail.com
- spec-cleaned spec file
- use geoclue2 instead geoclue
- Update to 1.10
  * Fix #80: Add Geoclue2 location provider.
  * Add hooks for user actions on period switch.
  * Be less verbose when color values/period did not change.
  * Add config setting to set gamma separately for day/night.
  * Add support for custom transition start and end elevation (Mattias Andrée).
  * redshift-gtk: Show errors from child process in a dialog.
  * Fix #95: Add AppData file for package managers.
  * Fix #41: Do not jump to 0 %% or 100 %% when changing direction of transition (Mattias Andrée).
  * redshift-gtk: Relay USR1 signal to redshift process.
  * redshift-gtk: Notify desktop about startup completion.
  * Fix: systemd unit files were built from the wrong source.
  * Fix #90: Print N/S and E/W in the location (Mattias Andrée).
  * Fix #112: redshift-gtk: Do not buffer lines from child indefinitely.
  * Fix #105: Limit decimals in displayed location to two.
  * Update dependencies listed in HACKING.md (emilf, Kees Hink).
  * Fix: Make desktop file translatable.
* Mon Nov 24 2014 robert.munteanu@gmail.com
- Update to 1.9.1
  * Fix: Do not distribute redshift-gtk, only redshift-gtk.in.
  * Fix: Geoclue support should pull in Glib as dependency.
  * geoclue: Fix segfault when error is NULL (Mattias Andrée).
  * geoclue: Set DISPLAY=:0 to work around issue when outside X (Mattias Andrée).
  * redshift-gtk: Fix crash when toggling state using the status icon.
  * redshift-gtk: Fix line splitting logic (Maks Verver).
-  Update to 1.9
  * Use improved color scheme provided by Ingo Thies.
  * Add drm driver which will apply adjustments on linux consoles (Mattias Andrée).
  * Remove deprecated GNOME clock location provider.
  * Set proc title for redshift-gtk (Linux/BSD) (Philipp Hagemeister).
  * Show current temperature, location and status in GUI.
  * Add systemd user unit files so that redshift can be used with systemd as a session manager (Henry de Valence).
  * Use checkbox to toggle Redshift in GUI (Mattias Andrée).
  * Gamma correction is applied after brightness and temperature (Mattias Andrée).
  * Use XDG Base Directory Specification when looking for configuration file (Mattias Andrée).
  * Load config from %%LOCALAPPDATA%%\redshift.conf on Windows (TingPing).
  * Add RPM spec for Fedora in contrib.
  * redshift-gtk has been ported to Python3 and new PyGObject bindings for Python.
* Wed Nov 27 2013 mailaender@opensuse.org
- Separate GUI and CLI application into different packages
* Mon Nov 25 2013 mailaender@opensuse.org
- Add missing GeoClue build dependency
- Update to 1.8
  * IMPORTANT: gtk-redshift has changed name to redshift-gtk.
  * Fix crash when starting geoclue provider. (Thanks to Maks Verver)
  * Fix slight flicker int gamme ramp values (Sean Hildebrand)
  * Add redshift-gtk option to suspend for a short time period (Jendrik Seipp).
  * Add print mode (prints parameters and exits) by Vincent Breitmoser.
  * Set buffering on stdout and stderr to line-buffered.
  * Allow separate brightness for day and night (Olivier Fabre and Jeremy Erickson).
  * Fix various crashes/bugs/typos (Benjamin Kerensa and others)
* Sat Aug 13 2011 pascal.bleser@opensuse.org
- add missing Requires on python-xdg
* Wed Jul 20 2011 tejas.guruswamy@opensuse.org
- Update to 1.7
  * GeoClue location provider support
  * Allow brightness to be adjusted (-b).
  * Provide option to set color temperature directly (Joe Hillenbrand).
  * Add option to show program version (-V).
* Thu Dec 30 2010 tejas.guruswamy@opensuse.org
- Update to 1.6
  * Support for optional configuration file (fixes #590722).
  * Add man page for redshift written by Andrew Starr-Bochicchio (fixes #582196).
  * Explain in help output that 6500K is the neutral color temperature (fixes #627113).
  * Fix: Handle multiple instances of the GNOME clock applet; contributed by Francesco Marella (fixes #610860).
  * Fix: Redshift crashes when VidMode fails (fixes #657451).
  * Fix: Toggle menu item should not be of class gtk.ImageMenuItem (fixes #620355).
  * Application launcher and autostart feature contributed by Francesco Marella (fixes #590550, #612710).
  * Improve GNOME location provider (patch by Gabriel de Perthuis) (fixes #598277).
  * New ubuntu-mono-dark icons that fit the color guidelines better. Contributed by aleth (semi-fixes #596536).
  * Improve error message when first adjustment method fails (fixes #596537).
* Tue Jun 29 2010 ajorgensen@novell.com
- First version for SUSE (1.4.1)
